# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ore/mgmt/v1beta/metric.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x01\n\x14PipelineTriggerCount\x12)\n\rtrigger_count\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0ctriggerCount\x12;\n\x06status\x18\x02 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03H\x00R\x06status\x88\x01\x01\x42\t\n\x07_status\"\xc8\x01\n\x1eGetPipelineTriggerCountRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x35\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x05start\x88\x01\x01\x12\x33\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x04stop\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stop\"\x81\x01\n\x1fGetPipelineTriggerCountResponse\x12^\n\x17pipeline_trigger_counts\x18\x01 \x03(\x0b\x32&.core.mgmt.v1beta.PipelineTriggerCountR\x15pipelineTriggerCounts\"\xc8\x01\n\x1c\x43reditConsumptionChartRecord\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x43\n\x0ctime_buckets\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x0btimeBuckets\x12\x1c\n\x06\x61mount\x18\x03 \x03(\x02\x42\x04\xe2\x41\x01\x03R\x06\x61mount\x12\x1c\n\x06source\x18\x04 \x01(\tB\x04\xe2\x41\x01\x03R\x06source\"\x9d\x02\n(ListCreditConsumptionChartRecordsRequest\x12\'\n\x0cnamespace_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x0bnamespaceId\x12\x32\n\x12\x61ggregation_window\x18\x02 \x01(\tH\x00R\x11\x61ggregationWindow\x88\x01\x01\x12\x35\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x05start\x88\x01\x01\x12\x33\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\x04stop\x88\x01\x01\x42\x15\n\x13_aggregation_windowB\x08\n\x06_startB\x07\n\x05_stop\"\xaa\x01\n)ListCreditConsumptionChartRecordsResponse\x12w\n credit_consumption_chart_records\x18\x01 \x03(\x0b\x32..core.mgmt.v1beta.CreditConsumptionChartRecordR\x1d\x63reditConsumptionChartRecordsJ\x04\x08\x02\x10\x03\"\xc6\x02\n\x1aPipelineTriggerTableRecord\x12\x1f\n\x0bpipeline_id\x18\x01 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x02 \x01(\tR\x0bpipelineUid\x12<\n\x17trigger_count_completed\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x15triggerCountCompleted\x12\x38\n\x15trigger_count_errored\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x13triggerCountErrored\x12\x34\n\x13pipeline_release_id\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\x06 \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid\"\xc5\x01\n&ListPipelineTriggerTableRecordsRequest\x12&\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x00R\x08pageSize\x88\x01\x01\x12(\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x01R\tpageToken\x88\x01\x01\x12!\n\x06\x66ilter\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01H\x02R\x06\x66ilter\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\t\n\x07_filter\"\xe3\x01\n\'ListPipelineTriggerTableRecordsResponse\x12q\n\x1epipeline_trigger_table_records\x18\x01 \x03(\x0b\x32,.core.mgmt.v1beta.PipelineTriggerTableRecordR\x1bpipelineTriggerTableRecords\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\"\x85\x01\n&ListPipelineTriggerChartRecordsRequest\x12-\n\x12\x61ggregation_window\x18\x01 \x01(\x05R\x11\x61ggregationWindow\x12!\n\x06\x66ilter\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"\x9c\x01\n\'ListPipelineTriggerChartRecordsResponse\x12q\n\x1epipeline_trigger_chart_records\x18\x01 \x03(\x0b\x32,.core.mgmt.v1beta.PipelineTriggerChartRecordR\x1bpipelineTriggerChartRecords\"\xed\x03\n\x1aPipelineTriggerChartRecord\x12\x1f\n\x0bpipeline_id\x18\x01 \x01(\tR\npipelineId\x12!\n\x0cpipeline_uid\x18\x02 \x01(\tR\x0bpipelineUid\x12\x39\n\x0ctrigger_mode\x18\x03 \x01(\x0e\x32\x16.core.mgmt.v1beta.ModeR\x0btriggerMode\x12\x36\n\x06status\x18\x04 \x01(\x0e\x32\x18.core.mgmt.v1beta.StatusB\x04\xe2\x41\x01\x03R\x06status\x12\x43\n\x0ctime_buckets\x18\x05 \x03(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x0btimeBuckets\x12+\n\x0etrigger_counts\x18\x06 \x03(\x05\x42\x04\xe2\x41\x01\x03R\rtriggerCounts\x12\x38\n\x15\x63ompute_time_duration\x18\x07 \x03(\x02\x42\x04\xe2\x41\x01\x03R\x13\x63omputeTimeDuration\x12\x34\n\x13pipeline_release_id\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x11pipelineReleaseId\x12\x36\n\x14pipeline_release_uid\x18\t \x01(\tB\x04\xe2\x41\x01\x03R\x12pipelineReleaseUid*;\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tMODE_SYNC\x10\x01\x12\x0e\n\nMODE_ASYNC\x10\x02*J\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10STATUS_COMPLETED\x10\x01\x12\x12\n\x0eSTATUS_ERRORED\x10\x02\x42\xc4\x01\n\x14\x63om.core.mgmt.v1betaB\x0bMetricProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\013MetricProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _PIPELINETRIGGERCOUNT.fields_by_name['trigger_count']._options = None
  _PIPELINETRIGGERCOUNT.fields_by_name['trigger_count']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCOUNT.fields_by_name['status']._options = None
  _PIPELINETRIGGERCOUNT.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _GETPIPELINETRIGGERCOUNTREQUEST.fields_by_name['namespace_id']._options = None
  _GETPIPELINETRIGGERCOUNTREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['namespace_id']._options = None
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['time_buckets']._options = None
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['time_buckets']._serialized_options = b'\342A\001\003'
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['amount']._options = None
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['amount']._serialized_options = b'\342A\001\003'
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['source']._options = None
  _CREDITCONSUMPTIONCHARTRECORD.fields_by_name['source']._serialized_options = b'\342A\001\003'
  _LISTCREDITCONSUMPTIONCHARTRECORDSREQUEST.fields_by_name['namespace_id']._options = None
  _LISTCREDITCONSUMPTIONCHARTRECORDSREQUEST.fields_by_name['namespace_id']._serialized_options = b'\342A\001\002'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_completed']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_completed']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_errored']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['trigger_count_errored']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERTABLERECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERTABLERECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _LISTPIPELINETRIGGERCHARTRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTPIPELINETRIGGERCHARTRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['status']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['status']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['time_buckets']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['time_buckets']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['trigger_counts']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['trigger_counts']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['compute_time_duration']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['compute_time_duration']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_id']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_id']._serialized_options = b'\342A\001\003'
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_uid']._options = None
  _PIPELINETRIGGERCHARTRECORD.fields_by_name['pipeline_release_uid']._serialized_options = b'\342A\001\003'
  _globals['_MODE']._serialized_start=2806
  _globals['_MODE']._serialized_end=2865
  _globals['_STATUS']._serialized_start=2867
  _globals['_STATUS']._serialized_end=2941
  _globals['_PIPELINETRIGGERCOUNT']._serialized_start=118
  _globals['_PIPELINETRIGGERCOUNT']._serialized_end=255
  _globals['_GETPIPELINETRIGGERCOUNTREQUEST']._serialized_start=258
  _globals['_GETPIPELINETRIGGERCOUNTREQUEST']._serialized_end=458
  _globals['_GETPIPELINETRIGGERCOUNTRESPONSE']._serialized_start=461
  _globals['_GETPIPELINETRIGGERCOUNTRESPONSE']._serialized_end=590
  _globals['_CREDITCONSUMPTIONCHARTRECORD']._serialized_start=593
  _globals['_CREDITCONSUMPTIONCHARTRECORD']._serialized_end=793
  _globals['_LISTCREDITCONSUMPTIONCHARTRECORDSREQUEST']._serialized_start=796
  _globals['_LISTCREDITCONSUMPTIONCHARTRECORDSREQUEST']._serialized_end=1081
  _globals['_LISTCREDITCONSUMPTIONCHARTRECORDSRESPONSE']._serialized_start=1084
  _globals['_LISTCREDITCONSUMPTIONCHARTRECORDSRESPONSE']._serialized_end=1254
  _globals['_PIPELINETRIGGERTABLERECORD']._serialized_start=1257
  _globals['_PIPELINETRIGGERTABLERECORD']._serialized_end=1583
  _globals['_LISTPIPELINETRIGGERTABLERECORDSREQUEST']._serialized_start=1586
  _globals['_LISTPIPELINETRIGGERTABLERECORDSREQUEST']._serialized_end=1783
  _globals['_LISTPIPELINETRIGGERTABLERECORDSRESPONSE']._serialized_start=1786
  _globals['_LISTPIPELINETRIGGERTABLERECORDSRESPONSE']._serialized_end=2013
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSREQUEST']._serialized_start=2016
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSREQUEST']._serialized_end=2149
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSRESPONSE']._serialized_start=2152
  _globals['_LISTPIPELINETRIGGERCHARTRECORDSRESPONSE']._serialized_end=2308
  _globals['_PIPELINETRIGGERCHARTRECORD']._serialized_start=2311
  _globals['_PIPELINETRIGGERCHARTRECORD']._serialized_end=2804
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class UnspecifiedInput(google.protobuf.message.Message):
    """UnspecifiedInput represents the input of an unspecified task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_INPUTS_FIELD_NUMBER: builtins.int
    @property
    def raw_inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """A list of values for the task."""
    def __init__(
        self,
        *,
        raw_inputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_inputs", b"raw_inputs"]) -> None: ...

global___UnspecifiedInput = UnspecifiedInput

@typing_extensions.final
class UnspecifiedOutput(google.protobuf.message.Message):
    """UnspecifiedOutput contains the result of an unspecified task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def raw_outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """The task outputs."""
    def __init__(
        self,
        *,
        raw_outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_outputs", b"raw_outputs"]) -> None: ...

global___UnspecifiedOutput = UnspecifiedOutput



# pylint: disable=no-member,wrong-import-position,no-name-in-module
from typing import Optional

import instill.protogen.model.model.v1alpha.model_definition_pb2 as model_definition_interface
import instill.protogen.model.model.v1alpha.model_pb2 as model_interface
from instill.clients import InstillClient
from instill.resources.resource import Resource


class Model(Resource):
    def __init__(
        self,
        client: InstillClient,
        name: str,
        definition: str,
        configuration: dict,
    ) -> None:
        super().__init__()
        self.client = client
        get_resp = client.model_service.get_model(model_name=name, silent=True)
        if get_resp is None:
            model = client.model_service.create_model(
                name=name,
                definition=definition,
                configuration=configuration,
            ).model
            if model is None:
                raise BaseException("model creation failed")
        else:
            model = get_resp.model

        self.resource = model

    def __call__(self, task_inputs: list, silent: bool = False) -> Optional[list]:
        response = self.client.model_service.trigger_model(
            self.resource.id,
            task_inputs,
            silent=silent,
        )
        if response is not None:
            return response.task_outputs
        return response

    @property
    def client(self):
        return self._client

    @client.setter
    def client(self, client: InstillClient):
        self._client = client

    @property
    def resource(self):
        return self._resource

    @resource.setter
    def resource(self, resource: model_interface.Model):
        self._resource = resource

    def _update(self):
        self.resource = self.client.model_service.get_model(
            model_name=self.resource.id
        ).model

    def get_definition(self) -> model_definition_interface.ModelDefinition:
        return self.resource.model_definition

    def delete(self, silent: bool = False):
        if self.resource is not None:
            self.client.model_service.delete_model(
                self.resource.id,
                silent=silent,
            )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/metric/v1beta/metric_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.metric.v1beta import metric_pb2 as core_dot_metric_dot_v1beta_dot_metric__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'core/metric/v1beta/metric_service.proto\x12\x12\x63ore.metric.v1beta\x1a\x1f\x63ore/metric/v1beta/metric.proto\x1a\x1bgoogle/api/visibility.proto2\xc3\x0c\n\x0fPipelineService\x12\x61\n\x0cGetPipelines\x12\'.core.metric.v1beta.GetPipelinesRequest\x1a(.core.metric.v1beta.GetPipelinesResponse\x12|\n\x15ReportPipelineTrigger\x12\x30.core.metric.v1beta.ReportPipelineTriggerRequest\x1a\x31.core.metric.v1beta.ReportPipelineTriggerResponse\x12\x7f\n\x16ReportPipelineTriggers\x12\x31.core.metric.v1beta.ReportPipelineTriggersRequest\x1a\x32.core.metric.v1beta.ReportPipelineTriggersResponse\x12\x88\x01\n\x19GetPipelineTriggerRecords\x12\x34.core.metric.v1beta.GetPipelineTriggerRecordsRequest\x1a\x35.core.metric.v1beta.GetPipelineTriggerRecordsResponse\x12\x94\x01\n\x1dGetBulkPipelineTriggerRecords\x12\x38.core.metric.v1beta.GetBulkPipelineTriggerRecordsRequest\x1a\x39.core.metric.v1beta.GetBulkPipelineTriggerRecordsResponse\x12\xa6\x01\n#GetCumulativePipelineTriggerRecords\x12>.core.metric.v1beta.GetCumulativePipelineTriggerRecordsRequest\x1a?.core.metric.v1beta.GetCumulativePipelineTriggerRecordsResponse\x12\xb2\x01\n\'GetBulkCumulativePipelineTriggerRecords\x12\x42.core.metric.v1beta.GetBulkCumulativePipelineTriggerRecordsRequest\x1a\x43.core.metric.v1beta.GetBulkCumulativePipelineTriggerRecordsResponse\x12\x88\x01\n\x19GetPipelineTriggerSummary\x12\x34.core.metric.v1beta.GetPipelineTriggerSummaryRequest\x1a\x35.core.metric.v1beta.GetPipelineTriggerSummaryResponse\x12\x9a\x01\n\x1fGetBulkPipelineTriggerSummaries\x12:.core.metric.v1beta.GetBulkPipelineTriggerSummariesRequest\x1a;.core.metric.v1beta.GetBulkPipelineTriggerSummariesResponse\x12\x82\x01\n\x17GetPipelineTriggerPrice\x12\x32.core.metric.v1beta.GetPipelineTriggerPriceRequest\x1a\x33.core.metric.v1beta.GetPipelineTriggerPriceResponse\x12\x8e\x01\n\x1bGetBulkPipelineTriggerPrice\x12\x36.core.metric.v1beta.GetBulkPipelineTriggerPriceRequest\x1a\x37.core.metric.v1beta.GetBulkPipelineTriggerPriceResponse\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL2\xb6\x0b\n\x0cModelService\x12X\n\tGetModels\x12$.core.metric.v1beta.GetModelsRequest\x1a%.core.metric.v1beta.GetModelsResponse\x12p\n\x11ReportModelOnline\x12,.core.metric.v1beta.ReportModelOnlineRequest\x1a-.core.metric.v1beta.ReportModelOnlineResponse\x12s\n\x12ReportModelOnlines\x12-.core.metric.v1beta.ReportModelOnlinesRequest\x1a..core.metric.v1beta.ReportModelOnlinesResponse\x12|\n\x15GetModelOnlineRecords\x12\x30.core.metric.v1beta.GetModelOnlineRecordsRequest\x1a\x31.core.metric.v1beta.GetModelOnlineRecordsResponse\x12\x88\x01\n\x19GetBulkModelOnlineRecords\x12\x34.core.metric.v1beta.GetBulkModelOnlineRecordsRequest\x1a\x35.core.metric.v1beta.GetBulkModelOnlineRecordsResponse\x12\x9a\x01\n\x1fGetCumulativeModelOnlineRecords\x12:.core.metric.v1beta.GetCumulativeModelOnlineRecordsRequest\x1a;.core.metric.v1beta.GetCumulativeModelOnlineRecordsResponse\x12\xa6\x01\n#GetBulkCumulativeModelOnlineRecords\x12>.core.metric.v1beta.GetBulkCumulativeModelOnlineRecordsRequest\x1a?.core.metric.v1beta.GetBulkCumulativeModelOnlineRecordsResponse\x12|\n\x15GetModelOnlineSummary\x12\x30.core.metric.v1beta.GetModelOnlineSummaryRequest\x1a\x31.core.metric.v1beta.GetModelOnlineSummaryResponse\x12\x88\x01\n\x19GetBulkModelOnlineSummary\x12\x34.core.metric.v1beta.GetBulkModelOnlineSummaryRequest\x1a\x35.core.metric.v1beta.GetBulkModelOnlineSummaryResponse\x12v\n\x13GetModelOnlinePrice\x12..core.metric.v1beta.GetModelOnlinePriceRequest\x1a/.core.metric.v1beta.GetModelOnlinePriceResponse\x12\x82\x01\n\x17GetBulkModelOnlinePrice\x12\x32.core.metric.v1beta.GetBulkModelOnlinePriceRequest\x1a\x33.core.metric.v1beta.GetBulkModelOnlinePriceResponse\x1a\x10\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNALB\xd9\x01\n\x16\x63om.core.metric.v1betaB\x12MetricServiceProtoP\x01ZAgithub.com/instill-ai/protogen-go/core/metric/v1beta;metricv1beta\xa2\x02\x03\x43MX\xaa\x02\x12\x43ore.Metric.V1beta\xca\x02\x12\x43ore\\Metric\\V1beta\xe2\x02\x1e\x43ore\\Metric\\V1beta\\GPBMetadata\xea\x02\x14\x43ore::Metric::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.metric.v1beta.metric_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.core.metric.v1betaB\022MetricServiceProtoP\001ZAgithub.com/instill-ai/protogen-go/core/metric/v1beta;metricv1beta\242\002\003CMX\252\002\022Core.Metric.V1beta\312\002\022Core\\Metric\\V1beta\342\002\036Core\\Metric\\V1beta\\GPBMetadata\352\002\024Core::Metric::V1beta'
  _PIPELINESERVICE._options = None
  _PIPELINESERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _MODELSERVICE._options = None
  _MODELSERVICE._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL'
  _globals['_PIPELINESERVICE']._serialized_start=126
  _globals['_PIPELINESERVICE']._serialized_end=1729
  _globals['_MODELSERVICE']._serialized_start=1732
  _globals['_MODELSERVICE']._serialized_end=3194
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import core.usage.v1beta.usage_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class UsageServiceStub:
    """UsageService responds to incoming usage requests."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Liveness: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.LivenessRequest,
        core.usage.v1beta.usage_pb2.LivenessResponse,
    ]
    """Liveness method receives a LivenessRequest message and returns a
    LivenessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    Readiness: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.ReadinessRequest,
        core.usage.v1beta.usage_pb2.ReadinessResponse,
    ]
    """Readiness method receives a ReadinessRequest message and returns a
    ReadinessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateSession: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.CreateSessionRequest,
        core.usage.v1beta.usage_pb2.CreateSessionResponse,
    ]
    """CreateSession method receives a CreateSessionRequest message and returns
    a CreateSessionResponse message.
    """
    SendSessionReport: grpc.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.SendSessionReportRequest,
        core.usage.v1beta.usage_pb2.SendSessionReportResponse,
    ]
    """SendSessionReport method receives a SendSessionReportRequest message and
    returns a SendSessionReportResponse message.
    """

class UsageServiceAsyncStub:
    """UsageService responds to incoming usage requests."""

    Liveness: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.LivenessRequest,
        core.usage.v1beta.usage_pb2.LivenessResponse,
    ]
    """Liveness method receives a LivenessRequest message and returns a
    LivenessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    Readiness: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.ReadinessRequest,
        core.usage.v1beta.usage_pb2.ReadinessResponse,
    ]
    """Readiness method receives a ReadinessRequest message and returns a
    ReadinessResponse message.
    See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
    """
    CreateSession: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.CreateSessionRequest,
        core.usage.v1beta.usage_pb2.CreateSessionResponse,
    ]
    """CreateSession method receives a CreateSessionRequest message and returns
    a CreateSessionResponse message.
    """
    SendSessionReport: grpc.aio.UnaryUnaryMultiCallable[
        core.usage.v1beta.usage_pb2.SendSessionReportRequest,
        core.usage.v1beta.usage_pb2.SendSessionReportResponse,
    ]
    """SendSessionReport method receives a SendSessionReportRequest message and
    returns a SendSessionReportResponse message.
    """

class UsageServiceServicer(metaclass=abc.ABCMeta):
    """UsageService responds to incoming usage requests."""

    @abc.abstractmethod
    def Liveness(
        self,
        request: core.usage.v1beta.usage_pb2.LivenessRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.LivenessResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.LivenessResponse]]:
        """Liveness method receives a LivenessRequest message and returns a
        LivenessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def Readiness(
        self,
        request: core.usage.v1beta.usage_pb2.ReadinessRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.ReadinessResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.ReadinessResponse]]:
        """Readiness method receives a ReadinessRequest message and returns a
        ReadinessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
    @abc.abstractmethod
    def CreateSession(
        self,
        request: core.usage.v1beta.usage_pb2.CreateSessionRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.CreateSessionResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.CreateSessionResponse]]:
        """CreateSession method receives a CreateSessionRequest message and returns
        a CreateSessionResponse message.
        """
    @abc.abstractmethod
    def SendSessionReport(
        self,
        request: core.usage.v1beta.usage_pb2.SendSessionReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.usage.v1beta.usage_pb2.SendSessionReportResponse, collections.abc.Awaitable[core.usage.v1beta.usage_pb2.SendSessionReportResponse]]:
        """SendSessionReport method receives a SendSessionReportRequest message and
        returns a SendSessionReportResponse message.
        """

def add_UsageServiceServicer_to_server(servicer: UsageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Chunk(google.protobuf.message.Message):
    """The Chunk message represents a chunk of data in the artifact system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_UID_FIELD_NUMBER: builtins.int
    RETRIEVABLE_FIELD_NUMBER: builtins.int
    START_POS_FIELD_NUMBER: builtins.int
    END_POS_FIELD_NUMBER: builtins.int
    TOKENS_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    ORIGINAL_FILE_UID_FIELD_NUMBER: builtins.int
    chunk_uid: builtins.str
    """unique identifier of the chunk"""
    retrievable: builtins.bool
    """whether the chunk is retrievable"""
    start_pos: builtins.int
    """start position of the chunk in the source file"""
    end_pos: builtins.int
    """end position of the chunk in the source file"""
    tokens: builtins.int
    """tokens of the chunk"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation time of the chunk"""
    original_file_uid: builtins.str
    """original file unique identifier"""
    def __init__(
        self,
        *,
        chunk_uid: builtins.str = ...,
        retrievable: builtins.bool = ...,
        start_pos: builtins.int = ...,
        end_pos: builtins.int = ...,
        tokens: builtins.int = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        original_file_uid: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_uid", b"chunk_uid", "create_time", b"create_time", "end_pos", b"end_pos", "original_file_uid", b"original_file_uid", "retrievable", b"retrievable", "start_pos", b"start_pos", "tokens", b"tokens"]) -> None: ...

global___Chunk = Chunk

@typing_extensions.final
class ListChunksRequest(google.protobuf.message.Message):
    """The ListChunksRequest message represents a request to list chunks in the artifact system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    KB_ID_FIELD_NUMBER: builtins.int
    FILE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner id (not uid)"""
    kb_id: builtins.str
    """knowledge base name (not uid)"""
    file_uid: builtins.str
    """unique identifier of the file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        kb_id: builtins.str = ...,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uid", b"file_uid", "kb_id", b"kb_id", "namespace_id", b"namespace_id"]) -> None: ...

global___ListChunksRequest = ListChunksRequest

@typing_extensions.final
class ListChunksResponse(google.protobuf.message.Message):
    """The ListChunksResponse message represents a response containing a list of chunks in the artifact system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chunk]:
        """repeated chunks"""
    def __init__(
        self,
        *,
        chunks: collections.abc.Iterable[global___Chunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunks", b"chunks"]) -> None: ...

global___ListChunksResponse = ListChunksResponse

@typing_extensions.final
class SourceFile(google.protobuf.message.Message):
    """The SourceFile message represents a source file in the artifact system."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINAL_FILE_UID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    original_file_uid: builtins.str
    """original file unique identifier"""
    content: builtins.str
    """content"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation time of the source file"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update time of the source file"""
    def __init__(
        self,
        *,
        original_file_uid: builtins.str = ...,
        content: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "create_time", b"create_time", "original_file_uid", b"original_file_uid", "update_time", b"update_time"]) -> None: ...

global___SourceFile = SourceFile

@typing_extensions.final
class GetSourceFileRequest(google.protobuf.message.Message):
    """get source file request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    KB_ID_FIELD_NUMBER: builtins.int
    FILE_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner id"""
    kb_id: builtins.str
    """knowledge base name"""
    file_uid: builtins.str
    """unique identifier of the original uploaded file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        kb_id: builtins.str = ...,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uid", b"file_uid", "kb_id", b"kb_id", "namespace_id", b"namespace_id"]) -> None: ...

global___GetSourceFileRequest = GetSourceFileRequest

@typing_extensions.final
class GetSourceFileResponse(google.protobuf.message.Message):
    """get source file response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FILE_FIELD_NUMBER: builtins.int
    @property
    def source_file(self) -> global___SourceFile:
        """source file(either orignal file or converted file)"""
    def __init__(
        self,
        *,
        source_file: global___SourceFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_file", b"source_file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_file", b"source_file"]) -> None: ...

global___GetSourceFileResponse = GetSourceFileResponse

@typing_extensions.final
class UpdateChunkRequest(google.protobuf.message.Message):
    """Create chunk response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_UID_FIELD_NUMBER: builtins.int
    RETRIEVABLE_FIELD_NUMBER: builtins.int
    chunk_uid: builtins.str
    """chunk uid"""
    retrievable: builtins.bool
    """whether the chunk is retrievable"""
    def __init__(
        self,
        *,
        chunk_uid: builtins.str = ...,
        retrievable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_uid", b"chunk_uid", "retrievable", b"retrievable"]) -> None: ...

global___UpdateChunkRequest = UpdateChunkRequest

@typing_extensions.final
class UpdateChunkResponse(google.protobuf.message.Message):
    """Updae chunk response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_FIELD_NUMBER: builtins.int
    @property
    def chunk(self) -> global___Chunk:
        """chunk"""
    def __init__(
        self,
        *,
        chunk: global___Chunk | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chunk", b"chunk"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk", b"chunk"]) -> None: ...

global___UpdateChunkResponse = UpdateChunkResponse

@typing_extensions.final
class SimilarityChunksSearchRequest(google.protobuf.message.Message):
    """Similar chunnk search request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    KB_ID_FIELD_NUMBER: builtins.int
    TEXT_PROMPT_FIELD_NUMBER: builtins.int
    TOPK_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner id"""
    kb_id: builtins.str
    """knowledge base name"""
    text_prompt: builtins.str
    """text prompt"""
    topk: builtins.int
    """topk"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        kb_id: builtins.str = ...,
        text_prompt: builtins.str = ...,
        topk: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kb_id", b"kb_id", "namespace_id", b"namespace_id", "text_prompt", b"text_prompt", "topk", b"topk"]) -> None: ...

global___SimilarityChunksSearchRequest = SimilarityChunksSearchRequest

@typing_extensions.final
class SimilarityChunksSearchResponse(google.protobuf.message.Message):
    """Similar chunnk search response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIMILAR_CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def similar_chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimilarityChunk]:
        """chunks"""
    def __init__(
        self,
        *,
        similar_chunks: collections.abc.Iterable[global___SimilarityChunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["similar_chunks", b"similar_chunks"]) -> None: ...

global___SimilarityChunksSearchResponse = SimilarityChunksSearchResponse

@typing_extensions.final
class SimilarityChunk(google.protobuf.message.Message):
    """similarity chunks"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNK_UID_FIELD_NUMBER: builtins.int
    SIMILARITY_SCORE_FIELD_NUMBER: builtins.int
    TEXT_CONTENT_FIELD_NUMBER: builtins.int
    SOURCE_FILE_FIELD_NUMBER: builtins.int
    chunk_uid: builtins.str
    """chunk uid"""
    similarity_score: builtins.float
    """similarity score"""
    text_content: builtins.str
    """chunk"""
    source_file: builtins.str
    """source file"""
    def __init__(
        self,
        *,
        chunk_uid: builtins.str = ...,
        similarity_score: builtins.float = ...,
        text_content: builtins.str = ...,
        source_file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_uid", b"chunk_uid", "similarity_score", b"similarity_score", "source_file", b"source_file", "text_content", b"text_content"]) -> None: ...

global___SimilarityChunk = SimilarityChunk



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vdp/pipeline/v1beta/pipeline_private_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from vdp.pipeline.v1beta import pipeline_pb2 as vdp_dot_pipeline_dot_v1beta_dot_pipeline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2vdp/pipeline/v1beta/pipeline_private_service.proto\x12\x13vdp.pipeline.v1beta\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\"vdp/pipeline/v1beta/pipeline.proto2\xd7\x03\n\x16PipelinePrivateService\x12w\n\x12ListPipelinesAdmin\x12..vdp.pipeline.v1beta.ListPipelinesAdminRequest\x1a/.vdp.pipeline.v1beta.ListPipelinesAdminResponse\"\x00\x12z\n\x13LookUpPipelineAdmin\x12/.vdp.pipeline.v1beta.LookUpPipelineAdminRequest\x1a\x30.vdp.pipeline.v1beta.LookUpPipelineAdminResponse\"\x00\x12\x8c\x01\n\x19ListPipelineReleasesAdmin\x12\x35.vdp.pipeline.v1beta.ListPipelineReleasesAdminRequest\x1a\x36.vdp.pipeline.v1beta.ListPipelineReleasesAdminResponse\"\x00\x1a\x39\x92\x41\x36\x12\x34Private methods to interact with Pipeline resources.B\xea\x01\n\x17\x63om.vdp.pipeline.v1betaB\x1bPipelinePrivateServiceProtoP\x01ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\xa2\x02\x03VPX\xaa\x02\x13Vdp.Pipeline.V1beta\xca\x02\x13Vdp\\Pipeline\\V1beta\xe2\x02\x1fVdp\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x15Vdp::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vdp.pipeline.v1beta.pipeline_private_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.vdp.pipeline.v1betaB\033PipelinePrivateServiceProtoP\001ZDgithub.com/instill-ai/protogen-go/vdp/pipeline/v1beta;pipelinev1beta\242\002\003VPX\252\002\023Vdp.Pipeline.V1beta\312\002\023Vdp\\Pipeline\\V1beta\342\002\037Vdp\\Pipeline\\V1beta\\GPBMetadata\352\002\025Vdp::Pipeline::V1beta'
  _PIPELINEPRIVATESERVICE._options = None
  _PIPELINEPRIVATESERVICE._serialized_options = b'\222A6\0224Private methods to interact with Pipeline resources.'
  _globals['_PIPELINEPRIVATESERVICE']._serialized_start=160
  _globals['_PIPELINEPRIVATESERVICE']._serialized_end=631
# @@protoc_insertion_point(module_scope)



# pylint: disable=no-member,wrong-import-position
from typing import Dict

from google.protobuf import field_mask_pb2

# common
import instill.protogen.common.healthcheck.v1beta.healthcheck_pb2 as healthcheck
import instill.protogen.common.task.v1alpha.task_pb2 as task_interface
import instill.protogen.model.model.v1alpha.model_definition_pb2 as model_definition_interface

# model
import instill.protogen.model.model.v1alpha.model_pb2 as model_interface
import instill.protogen.model.model.v1alpha.model_public_service_pb2_grpc as model_service
from instill.clients.base import Client, RequestFactory
from instill.clients.constant import DEFAULT_INSTANCE
from instill.clients.instance import InstillInstance
from instill.configuration import global_config
from instill.utils.error_handler import grpc_handler


class ModelClient(Client):
    def __init__(self, namespace: str, async_enabled: bool) -> None:
        self.hosts: Dict[str, InstillInstance] = {}
        self.namespace: str = namespace
        if DEFAULT_INSTANCE in global_config.hosts:
            self.instance = DEFAULT_INSTANCE
        elif len(global_config.hosts) == 0:
            self.instance = ""
        else:
            self.instance = list(global_config.hosts.keys())[0]

        if global_config.hosts is not None:
            for instance, config in global_config.hosts.items():
                self.hosts[instance] = InstillInstance(
                    model_service.ModelPublicServiceStub,
                    url=config.url,
                    token=config.token,
                    secure=config.secure,
                    async_enabled=async_enabled,
                )

    @property
    def hosts(self):
        return self._hosts

    @hosts.setter
    def hosts(self, hosts: str):
        self._hosts = hosts

    @property
    def instance(self):
        return self._instance

    @instance.setter
    def instance(self, instance: str):
        self._instance = instance

    @property
    def metadata(self):
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: str):
        self._metadata = metadata

    def liveness(self, async_enabled: bool = False) -> model_interface.LivenessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.Liveness,
                request=model_interface.LivenessRequest(),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.Liveness,
            request=model_interface.LivenessRequest(),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    def readiness(
        self, async_enabled: bool = False
    ) -> model_interface.ReadinessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.Readiness,
                request=model_interface.ReadinessRequest(),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.Readiness,
            request=model_interface.ReadinessRequest(),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    def is_serving(self) -> bool:
        try:
            return (
                self.readiness().health_check_response.status
                == healthcheck.HealthCheckResponse.SERVING_STATUS_SERVING
            )
        except Exception:
            return False

    @grpc_handler
    def watch_model(
        self,
        model_name: str,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.WatchUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.WatchUserModel,
                request=model_interface.WatchUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.WatchUserModel,
            request=model_interface.WatchUserModelRequest(
                name=f"{self.namespace}/models/{model_name}"
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def watch_latest_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.WatchUserLatestModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.WatchUserLatestModel,
                request=model_interface.WatchUserLatestModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.WatchUserLatestModel,
            request=model_interface.WatchUserLatestModelRequest(
                name=f"{self.namespace}/models/{model_name}",
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def create_model(
        self,
        name: str,
        task: task_interface.Task.ValueType,
        region: str,
        hardware: str,
        definition: str,
        configuration: dict,
        visibility: model_interface.Model.Visibility.ValueType = model_interface.Model.VISIBILITY_PUBLIC,
        async_enabled: bool = False,
    ) -> model_interface.CreateUserModelResponse:
        model = model_interface.Model()
        model.id = name
        model.task = task
        model.region = region
        model.hardware = hardware
        model.model_definition = definition
        model.visibility = visibility
        model.configuration.Clear()
        model.configuration.update(configuration)
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.CreateUserModel,
                request=model_interface.CreateUserModelRequest(
                    model=model, parent=self.namespace
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.CreateUserModel,
            request=model_interface.CreateUserModelRequest(
                model=model, parent=self.namespace
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_model(
        self,
        model_name: str,
        task_inputs: list[model_interface.TaskInput],
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.TriggerUserModel,
                request=model_interface.TriggerUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerUserModel,
            request=model_interface.TriggerUserModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_async_model(
        self,
        model_name: str,
        task_inputs: list[model_interface.TaskInput],
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerAsyncUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.TriggerAsyncUserModel,
                request=model_interface.TriggerAsyncUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerAsyncUserModel,
            request=model_interface.TriggerAsyncUserModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_latest_model(
        self,
        model_name: str,
        task_inputs: list[model_interface.TaskInput],
        async_enabled: bool = False,
    ) -> model_interface.TriggerUserLatestModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.TriggerUserLatestModel,
                request=model_interface.TriggerUserLatestModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerUserLatestModel,
            request=model_interface.TriggerUserLatestModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_async_latest_model(
        self,
        model_name: str,
        task_inputs: list[model_interface.TaskInput],
        async_enabled: bool = False,
    ) -> model_interface.TriggerAsyncUserLatestModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.TriggerAsyncUserLatestModel,
                request=model_interface.TriggerAsyncUserLatestModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerAsyncUserLatestModel,
            request=model_interface.TriggerAsyncUserLatestModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_model_binary_file_upload(
        self,
        model_name: str,
        task_input: model_interface.TaskInputStream,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerUserModelBinaryFileUploadResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.TriggerUserModelBinaryFileUpload,
                request=model_interface.TriggerUserModelBinaryFileUploadRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_input=task_input,
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerUserModelBinaryFileUpload,
            request=model_interface.TriggerUserModelBinaryFileUploadRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_input=task_input,
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def delete_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.DeleteUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.DeleteUserModel,
                request=model_interface.DeleteUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeleteUserModel,
            request=model_interface.DeleteUserModelRequest(
                name=f"{self.namespace}/models/{model_name}"
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def rename_model(
        self,
        model_name: str,
        new_model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.RenameUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.RenameUserModel,
                request=model_interface.RenameUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    new_model_id=new_model_id,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.RenameUserModel,
            request=model_interface.RenameUserModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                new_model_id=new_model_id,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.GetUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetUserModel,
                request=model_interface.GetUserModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetUserModel,
            request=model_interface.GetUserModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def update_model(
        self,
        model: model_interface.Model,
        mask: field_mask_pb2.FieldMask,
        async_enabled: bool = False,
    ) -> model_interface.UpdateUserModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.UpdateUserModel,
                request=model_interface.UpdateUserModelRequest(
                    model=model,
                    update_mask=mask,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.UpdateUserModel,
            request=model_interface.UpdateUserModelRequest(
                model=model,
                update_mask=mask,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def lookup_model(
        self,
        model_uid: str,
        async_enabled: bool = False,
    ) -> model_interface.LookUpModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.LookUpModel,
                request=model_interface.LookUpModelRequest(
                    permalink=f"models/{model_uid}"
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.LookUpModel,
            request=model_interface.LookUpModelRequest(permalink=f"models/{model_uid}"),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_models(
        self,
        visibility: model_interface.Model.Visibility.ValueType = model_interface.Model.VISIBILITY_PUBLIC,
        next_page_token: str = "",
        total_size: int = 100,
        show_deleted: bool = False,
        public=False,
        filter_str: str = "",
        order_by: str = "",
        async_enabled: bool = False,
    ) -> model_interface.ListUserModelsResponse:
        if async_enabled:
            if public:
                method = self.hosts[self.instance].async_client.ListModels
                return RequestFactory(
                    method=method,
                    request=model_interface.ListModelsRequest(
                        page_size=total_size,
                        page_token=next_page_token,
                        show_deleted=show_deleted,
                        view=model_definition_interface.VIEW_FULL,
                        filter=filter_str,
                        visibility=visibility,
                        order_by=order_by,
                    ),
                    metadata=self.hosts[self.instance].metadata,
                ).send_async()
            method = self.hosts[self.instance].async_client.ListUserModels
            return RequestFactory(
                method=method,
                request=model_interface.ListUserModelsRequest(
                    parent=self.namespace,
                    page_size=total_size,
                    page_token=next_page_token,
                    show_deleted=show_deleted,
                    view=model_definition_interface.VIEW_FULL,
                    filter=filter_str,
                    visibility=visibility,
                    order_by=order_by,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()
        if public:
            method = self.hosts[self.instance].client.ListModels
            return RequestFactory(
                method=method,
                request=model_interface.ListModelsRequest(
                    page_size=total_size,
                    page_token=next_page_token,
                    show_deleted=show_deleted,
                    view=model_definition_interface.VIEW_FULL,
                    filter=filter_str,
                    visibility=visibility,
                    order_by=order_by,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_sync()
        method = self.hosts[self.instance].client.ListUserModels
        return RequestFactory(
            method=method,
            request=model_interface.ListUserModelsRequest(
                parent=self.namespace,
                page_size=total_size,
                page_token=next_page_token,
                show_deleted=show_deleted,
                view=model_definition_interface.VIEW_FULL,
                filter=filter_str,
                visibility=visibility,
                order_by=order_by,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_model_definitions(
        self,
        page_size: int = 100,
        page_token: str = "",
        async_enabled: bool = False,
    ) -> model_definition_interface.ListModelDefinitionsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ListModelDefinitions,
                request=model_definition_interface.ListModelDefinitionsRequest(
                    page_size=page_size,
                    page_token=page_token,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListModelDefinitions,
            request=model_definition_interface.ListModelDefinitionsRequest(
                page_size=page_size,
                page_token=page_token,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_available_regions(
        self,
        async_enabled: bool = False,
    ) -> model_interface.ListAvailableRegionsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ListAvailableRegions,
                request=model_interface.ListAvailableRegionsRequest(),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListAvailableRegions,
            request=model_interface.ListAvailableRegionsRequest(),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_model_definition(
        self,
        model_definition_id: str,
        async_enabled: bool = False,
    ) -> model_definition_interface.GetModelDefinitionResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetModelDefinition,
                request=model_definition_interface.GetModelDefinitionRequest(
                    view=model_definition_interface.VIEW_FULL,
                    model_definition_id=model_definition_id,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetModelDefinition,
            request=model_definition_interface.GetModelDefinitionRequest(
                view=model_definition_interface.VIEW_FULL,
                model_definition_id=model_definition_id,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_operation(
        self,
        operation_id: str,
        async_enabled: bool = False,
    ) -> model_interface.GetModelOperationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetModelOperation,
                request=model_interface.GetModelOperationRequest(
                    operation_id=operation_id,
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetModelOperation,
            request=model_interface.GetModelOperationRequest(
                operation_id=operation_id,
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_latest_model_operation(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.GetUserLatestModelOperationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.GetUserLatestModelOperation,
                request=model_interface.GetUserLatestModelOperationRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetUserLatestModelOperation,
            request=model_interface.GetUserLatestModelOperationRequest(
                name=f"{self.namespace}/models/{model_name}",
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_organization_latest_model_operation(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.GetOrganizationLatestModelOperationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.GetOrganizationLatestModelOperation,
                request=model_interface.GetOrganizationLatestModelOperationRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetOrganizationLatestModelOperation,
            request=model_interface.GetOrganizationLatestModelOperationRequest(
                name=f"{self.namespace}/models/{model_name}",
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_model_versions(
        self,
        page: int,
        model_name: str,
        page_size: int = 100,
        async_enabled: bool = False,
    ) -> model_interface.ListUserModelVersionsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ListUserModelVersions,
                request=model_interface.ListUserModelVersionsRequest(
                    page_size=page_size,
                    page=page,
                    name=f"{self.namespace}/models/{model_name}",
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListUserModelVersions,
            request=model_interface.ListUserModelVersionsRequest(
                page_size=page_size,
                page=page,
                name=f"{self.namespace}/models/{model_name}",
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def delete_model_version(
        self,
        model_name: str,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.DeleteUserModelVersionResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.DeleteUserModelVersion,
                request=model_interface.DeleteUserModelVersionRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeleteUserModelVersion,
            request=model_interface.DeleteUserModelVersionRequest(
                name=f"{self.namespace}/models/{model_name}",
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_organization_models(
        self,
        page_size: int = 100,
        page_token: str = "",
        parent: str = "",
        show_deleted: bool = False,
        # filter: str = "",
        order_by: str = "",
        async_enabled: bool = False,
    ) -> model_interface.ListOrganizationModelsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.ListOrganizationModels,
                request=model_interface.ListOrganizationModelsRequest(
                    page_size=page_size,
                    page_token=page_token,
                    view=model_definition_interface.VIEW_FULL,
                    parent=parent,
                    show_deleted=show_deleted,
                    # filter=filter,
                    # visibility=visibility,
                    order_by=order_by,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListOrganizationModels,
            request=model_interface.ListOrganizationModelsRequest(
                page_size=page_size,
                page_token=page_token,
                view=model_definition_interface.VIEW_FULL,
                parent=parent,
                show_deleted=show_deleted,
                # filter=filter,
                # visibility=visibility,
                order_by=order_by,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def create_organization_model(
        self,
        name: str,
        definition: str,
        configuration: dict,
        parent: str,
        async_enabled: bool = False,
    ) -> model_interface.CreateOrganizationModelResponse:
        model = model_interface.Model()
        model.id = name
        model.model_definition = definition
        model.configuration.update(configuration)

        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.CreateOrganizationModel,
                request=model_interface.CreateOrganizationModelRequest(
                    model=model,
                    parent=parent,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.CreateOrganizationModel,
            request=model_interface.CreateOrganizationModelRequest(
                model=model,
                parent=parent,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def get_organization_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.GetOrganizationModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.GetOrganizationModel,
                request=model_interface.GetOrganizationModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    view=model_definition_interface.VIEW_FULL,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.GetOrganizationModel,
            request=model_interface.GetOrganizationModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                view=model_definition_interface.VIEW_FULL,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def update_organization_model(
        self,
        model: model_interface.Model,
        update_mask: field_mask_pb2.FieldMask,
        async_enabled: bool = False,
    ) -> model_interface.UpdateOrganizationModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.UpdateOrganizationModel,
                request=model_interface.UpdateOrganizationModelRequest(
                    model=model,
                    update_mask=update_mask,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.UpdateOrganizationModel,
            request=model_interface.UpdateOrganizationModelRequest(
                model=model,
                update_mask=update_mask,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def delete_organization_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.DeleteOrganizationModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.DeleteOrganizationModel,
                request=model_interface.DeleteOrganizationModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeleteOrganizationModel,
            request=model_interface.DeleteOrganizationModelRequest(
                name=f"{self.namespace}/models/{model_name}",
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def rename_organization_model(
        self,
        model_name: str,
        new_model_id: str,
        async_enabled: bool = False,
    ) -> model_interface.RenameOrganizationModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.RenameOrganizationModel,
                request=model_interface.RenameOrganizationModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    new_model_id=new_model_id,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.RenameOrganizationModel,
            request=model_interface.RenameOrganizationModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                new_model_id=new_model_id,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def watch_organization_model(
        self,
        model_name: str,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.WatchOrganizationModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.WatchOrganizationModel,
                request=model_interface.WatchOrganizationModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.WatchOrganizationModel,
            request=model_interface.WatchOrganizationModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def watch_organization_latest_model(
        self,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.WatchOrganizationLatestModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.WatchOrganizationLatestModel,
                request=model_interface.WatchOrganizationLatestModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.WatchOrganizationLatestModel,
            request=model_interface.WatchOrganizationLatestModelRequest(
                name=f"{self.namespace}/models/{model_name}",
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def list_organization_model_versions(
        self,
        page_size: int,
        page: int,
        model_name: str,
        async_enabled: bool = False,
    ) -> model_interface.ListOrganizationModelVersionsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.ListOrganizationModelVersions,
                request=model_interface.ListOrganizationModelVersionsRequest(
                    page_size=page_size,
                    page=page,
                    name=f"{self.namespace}/models/{model_name}",
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.ListOrganizationModelVersions,
            request=model_interface.ListOrganizationModelVersionsRequest(
                page_size=page_size,
                page=page,
                name=f"{self.namespace}/models/{model_name}",
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def delete_organization_model_version(
        self,
        model_name: str,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.DeleteOrganizationModelVersionResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.DeleteOrganizationModelVersion,
                request=model_interface.DeleteOrganizationModelVersionRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.DeleteOrganizationModelVersion,
            request=model_interface.DeleteOrganizationModelVersionRequest(
                name=f"{self.namespace}/models/{model_name}",
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_organization_model(
        self,
        model_name: str,
        task_inputs: list,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerOrganizationModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[self.instance].async_client.TriggerOrganizationModel,
                request=model_interface.TriggerOrganizationModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerOrganizationModel,
            request=model_interface.TriggerOrganizationModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_async_organization_model(
        self,
        model_name: str,
        task_inputs: list,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerAsyncOrganizationModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.TriggerAsyncOrganizationModel,
                request=model_interface.TriggerAsyncOrganizationModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerAsyncOrganizationModel,
            request=model_interface.TriggerAsyncOrganizationModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_organization_latest_model(
        self,
        model_name: str,
        task_inputs: list,
        async_enabled: bool = False,
    ) -> model_interface.TriggerOrganizationLatestModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.TriggerOrganizationLatestModel,
                request=model_interface.TriggerOrganizationLatestModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerOrganizationLatestModel,
            request=model_interface.TriggerOrganizationLatestModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_async_organization_latest_model(
        self,
        model_name: str,
        task_inputs: list,
        async_enabled: bool = False,
    ) -> model_interface.TriggerAsyncOrganizationLatestModelResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.TriggerAsyncOrganizationLatestModel,
                request=model_interface.TriggerAsyncOrganizationLatestModelRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    task_inputs=task_inputs,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[self.instance].client.TriggerAsyncOrganizationLatestModel,
            request=model_interface.TriggerAsyncOrganizationLatestModelRequest(
                name=f"{self.namespace}/models/{model_name}",
                task_inputs=task_inputs,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()

    @grpc_handler
    def trigger_organization_model_binary_file_upload(
        self,
        model_name: str,
        # task_input: list,
        version: str,
        async_enabled: bool = False,
    ) -> model_interface.TriggerOrganizationModelBinaryFileUploadResponse:
        if async_enabled:
            return RequestFactory(
                method=self.hosts[
                    self.instance
                ].async_client.TriggerOrganizationModelBinaryFileUpload,
                request=model_interface.TriggerOrganizationModelBinaryFileUploadRequest(
                    name=f"{self.namespace}/models/{model_name}",
                    # task_input=task_input,
                    version=version,
                ),
                metadata=self.hosts[self.instance].metadata,
            ).send_async()

        return RequestFactory(
            method=self.hosts[
                self.instance
            ].client.TriggerOrganizationModelBinaryFileUpload,
            request=model_interface.TriggerOrganizationModelBinaryFileUploadRequest(
                name=f"{self.namespace}/models/{model_name}",
                # task_input=task_input,
                version=version,
            ),
            metadata=self.hosts[self.instance].metadata,
        ).send_sync()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/mgmt/v1beta/mgmt_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from core.mgmt.v1beta import metric_pb2 as core_dot_mgmt_dot_v1beta_dot_metric__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*core/mgmt/v1beta/mgmt_public_service.proto\x12\x10\x63ore.mgmt.v1beta\x1a\x1d\x63ore/mgmt/v1beta/metric.proto\x1a\x1b\x63ore/mgmt/v1beta/mgmt.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xec\x32\n\x11MgmtPublicService\x12\x94\x01\n\x08Liveness\x12!.core.mgmt.v1beta.LivenessRequest\x1a\".core.mgmt.v1beta.LivenessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x12/v1beta/__livenessZ\x15\x12\x13/v1beta/health/mgmt\x12\x97\x01\n\tReadiness\x12\".core.mgmt.v1beta.ReadinessRequest\x1a#.core.mgmt.v1beta.ReadinessResponse\"A\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12\x13/v1beta/__readinessZ\x14\x12\x12/v1beta/ready/mgmt\x12\x94\x01\n\x14GetAuthenticatedUser\x12-.core.mgmt.v1beta.GetAuthenticatedUserRequest\x1a..core.mgmt.v1beta.GetAuthenticatedUserResponse\"\x1d\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1beta/user\x12\xa0\x01\n\x16PatchAuthenticatedUser\x12/.core.mgmt.v1beta.PatchAuthenticatedUserRequest\x1a\x30.core.mgmt.v1beta.PatchAuthenticatedUserResponse\"#\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x14\x32\x0c/v1beta/user:\x04user\x12t\n\tListUsers\x12\".core.mgmt.v1beta.ListUsersRequest\x1a#.core.mgmt.v1beta.ListUsersResponse\"\x1e\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x0f\x12\r/v1beta/users\x12x\n\x07GetUser\x12 .core.mgmt.v1beta.GetUserRequest\x1a!.core.mgmt.v1beta.GetUserResponse\"(\x92\x41\x06\n\x04User\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta/users/{user_id}\x12\xad\x01\n\x12\x43reateOrganization\x12+.core.mgmt.v1beta.CreateOrganizationRequest\x1a,.core.mgmt.v1beta.CreateOrganizationResponse\"<\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02%\"\x15/v1beta/organizations:\x0corganization\x12\x9c\x01\n\x11ListOrganizations\x12*.core.mgmt.v1beta.ListOrganizationsRequest\x1a+.core.mgmt.v1beta.ListOrganizationsResponse\".\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02\x17\x12\x15/v1beta/organizations\x12\xa8\x01\n\x0fGetOrganization\x12(.core.mgmt.v1beta.GetOrganizationRequest\x1a).core.mgmt.v1beta.GetOrganizationResponse\"@\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02)\x12\'/v1beta/organizations/{organization_id}\x12\xbf\x01\n\x12UpdateOrganization\x12+.core.mgmt.v1beta.UpdateOrganizationRequest\x1a,.core.mgmt.v1beta.UpdateOrganizationResponse\"N\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02\x37\x32\'/v1beta/organizations/{organization_id}:\x0corganization\x12\xb1\x01\n\x12\x44\x65leteOrganization\x12+.core.mgmt.v1beta.DeleteOrganizationRequest\x1a,.core.mgmt.v1beta.DeleteOrganizationResponse\"@\x92\x41\x0e\n\x0cOrganization\x82\xd3\xe4\x93\x02)*\'/v1beta/organizations/{organization_id}\x12\xae\x01\n\x13ListUserMemberships\x12,.core.mgmt.v1beta.ListUserMembershipsRequest\x1a-.core.mgmt.v1beta.ListUserMembershipsResponse\":\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02%\x12#/v1beta/users/{user_id}/memberships\x12\xba\x01\n\x11GetUserMembership\x12*.core.mgmt.v1beta.GetUserMembershipRequest\x1a+.core.mgmt.v1beta.GetUserMembershipResponse\"L\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta/users/{user_id}/memberships/{organization_id}\x12\xcf\x01\n\x14UpdateUserMembership\x12-.core.mgmt.v1beta.UpdateUserMembershipRequest\x1a..core.mgmt.v1beta.UpdateUserMembershipResponse\"X\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x43\x1a\x35/v1beta/users/{user_id}/memberships/{organization_id}:\nmembership\x12\xc3\x01\n\x14\x44\x65leteUserMembership\x12-.core.mgmt.v1beta.DeleteUserMembershipRequest\x1a..core.mgmt.v1beta.DeleteUserMembershipResponse\"L\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x37*5/v1beta/users/{user_id}/memberships/{organization_id}\x12\xd6\x01\n\x1bListOrganizationMemberships\x12\x34.core.mgmt.v1beta.ListOrganizationMembershipsRequest\x1a\x35.core.mgmt.v1beta.ListOrganizationMembershipsResponse\"J\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta/organizations/{organization_id}/memberships\x12\xda\x01\n\x19GetOrganizationMembership\x12\x32.core.mgmt.v1beta.GetOrganizationMembershipRequest\x1a\x33.core.mgmt.v1beta.GetOrganizationMembershipResponse\"T\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02?\x12=/v1beta/organizations/{organization_id}/memberships/{user_id}\x12\xef\x01\n\x1cUpdateOrganizationMembership\x12\x35.core.mgmt.v1beta.UpdateOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.UpdateOrganizationMembershipResponse\"`\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02K\x1a=/v1beta/organizations/{organization_id}/memberships/{user_id}:\nmembership\x12\xe3\x01\n\x1c\x44\x65leteOrganizationMembership\x12\x35.core.mgmt.v1beta.DeleteOrganizationMembershipRequest\x1a\x36.core.mgmt.v1beta.DeleteOrganizationMembershipResponse\"T\x92\x41\x0c\n\nMembership\x82\xd3\xe4\x93\x02?*=/v1beta/organizations/{organization_id}/memberships/{user_id}\x12\xcd\x01\n GetAuthenticatedUserSubscription\x12\x39.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionRequest\x1a:.core.mgmt.v1beta.GetAuthenticatedUserSubscriptionResponse\"2\x92\x41\x0e\n\x0cSubscription\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1beta/user/subscription\x12\xd9\x01\n\x1bGetOrganizationSubscription\x12\x34.core.mgmt.v1beta.GetOrganizationSubscriptionRequest\x1a\x35.core.mgmt.v1beta.GetOrganizationSubscriptionResponse\"M\x92\x41\x0e\n\x0cSubscription\x82\xd3\xe4\x93\x02\x36\x12\x34/v1beta/organizations/{organization_id}/subscription\x12\x83\x01\n\x0b\x43reateToken\x12$.core.mgmt.v1beta.CreateTokenRequest\x1a%.core.mgmt.v1beta.CreateTokenResponse\"\'\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x17\"\x0e/v1beta/tokens:\x05token\x12y\n\nListTokens\x12#.core.mgmt.v1beta.ListTokensRequest\x1a$.core.mgmt.v1beta.ListTokensResponse\" \x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1beta/tokens\x12~\n\x08GetToken\x12!.core.mgmt.v1beta.GetTokenRequest\x1a\".core.mgmt.v1beta.GetTokenResponse\"+\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1beta/tokens/{token_id}\x12\x87\x01\n\x0b\x44\x65leteToken\x12$.core.mgmt.v1beta.DeleteTokenRequest\x1a%.core.mgmt.v1beta.DeleteTokenResponse\"+\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x1b*\x19/v1beta/tokens/{token_id}\x12\x8a\x01\n\rValidateToken\x12&.core.mgmt.v1beta.ValidateTokenRequest\x1a\'.core.mgmt.v1beta.ValidateTokenResponse\"(\x92\x41\x07\n\x05Token\x82\xd3\xe4\x93\x02\x18\"\x16/v1beta/validate_token\x12\xac\x01\n\x12GetRemainingCredit\x12+.core.mgmt.v1beta.GetRemainingCreditRequest\x1a,.core.mgmt.v1beta.GetRemainingCreditResponse\";\x92\x41\x08\n\x06\x43redit\x82\xd3\xe4\x93\x02*\x12(/v1beta/namespaces/{namespace_id}/credit\x12\x91\x01\n\x0e\x43heckNamespace\x12\'.core.mgmt.v1beta.CheckNamespaceRequest\x1a(.core.mgmt.v1beta.CheckNamespaceResponse\",\x92\x41\x07\n\x05Utils\x82\xd3\xe4\x93\x02\x1c\"\x17/v1beta/check-namespace:\x01*\x12\xcd\x01\n\x17GetPipelineTriggerCount\x12\x30.core.mgmt.v1beta.GetPipelineTriggerCountRequest\x1a\x31.core.mgmt.v1beta.GetPipelineTriggerCountResponse\"M\x92\x41\x08\n\x06Metric\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12*/v1beta/metrics/vdp/pipeline/trigger-count\x12\xd1\x01\n\x1fListPipelineTriggerTableRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerTableRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerTableRecordsResponse\"9\x88\x02\x01\x92\x41\x08\n\x06Metric\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/tables\x12\xce\x01\n\x1fListPipelineTriggerChartRecords\x12\x38.core.mgmt.v1beta.ListPipelineTriggerChartRecordsRequest\x1a\x39.core.mgmt.v1beta.ListPipelineTriggerChartRecordsResponse\"6\x92\x41\x08\n\x06Metric\x82\xd3\xe4\x93\x02%\x12#/v1beta/metrics/vdp/pipeline/charts\x12\xce\x01\n!ListCreditConsumptionChartRecords\x12:.core.mgmt.v1beta.ListCreditConsumptionChartRecordsRequest\x1a;.core.mgmt.v1beta.ListCreditConsumptionChartRecordsResponse\"0\x92\x41\x08\n\x06Metric\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1beta/metrics/credit/charts\x12\x9c\x01\n\x0f\x41uthTokenIssuer\x12(.core.mgmt.v1beta.AuthTokenIssuerRequest\x1a).core.mgmt.v1beta.AuthTokenIssuerResponse\"4\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x1e\"\x19/v1beta/auth/token_issuer:\x01*\x12\x80\x01\n\tAuthLogin\x12\".core.mgmt.v1beta.AuthLoginRequest\x1a#.core.mgmt.v1beta.AuthLoginResponse\"*\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x14\"\x12/v1beta/auth/login\x12\x84\x01\n\nAuthLogout\x12#.core.mgmt.v1beta.AuthLogoutRequest\x1a$.core.mgmt.v1beta.AuthLogoutResponse\"+\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x15\"\x13/v1beta/auth/logout\x12\xa8\x01\n\x12\x41uthChangePassword\x12+.core.mgmt.v1beta.AuthChangePasswordRequest\x1a,.core.mgmt.v1beta.AuthChangePasswordResponse\"7\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02!\"\x1c/v1beta/auth/change_password:\x01*\x12\xba\x01\n\x17\x41uthValidateAccessToken\x12\x30.core.mgmt.v1beta.AuthValidateAccessTokenRequest\x1a\x31.core.mgmt.v1beta.AuthValidateAccessTokenResponse\":\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02$\"\"/v1beta/auth/validate_access_token\x1a\x1a\x92\x41\x17\x12\x15Public Core endpointsB\xcf\x01\n\x14\x63om.core.mgmt.v1betaB\x16MgmtPublicServiceProtoP\x01Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\xa2\x02\x03\x43MX\xaa\x02\x10\x43ore.Mgmt.V1beta\xca\x02\x10\x43ore\\Mgmt\\V1beta\xe2\x02\x1c\x43ore\\Mgmt\\V1beta\\GPBMetadata\xea\x02\x12\x43ore::Mgmt::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core.mgmt.v1beta.mgmt_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.core.mgmt.v1betaB\026MgmtPublicServiceProtoP\001Z=github.com/instill-ai/protogen-go/core/mgmt/v1beta;mgmtv1beta\242\002\003CMX\252\002\020Core.Mgmt.V1beta\312\002\020Core\\Mgmt\\V1beta\342\002\034Core\\Mgmt\\V1beta\\GPBMetadata\352\002\022Core::Mgmt::V1beta'
  _MGMTPUBLICSERVICE._options = None
  _MGMTPUBLICSERVICE._serialized_options = b'\222A\027\022\025Public Core endpoints'
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\022/v1beta/__livenessZ\025\022\023/v1beta/health/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022\023/v1beta/__readinessZ\024\022\022/v1beta/ready/mgmt'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUser']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\016\022\014/v1beta/user'
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['PatchAuthenticatedUser']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\0242\014/v1beta/user:\004user'
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUsers']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\017\022\r/v1beta/users'
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUser']._serialized_options = b'\222A\006\n\004User\202\323\344\223\002\031\022\027/v1beta/users/{user_id}'
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002%\"\025/v1beta/organizations:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizations']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002\027\022\025/v1beta/organizations'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002)\022\'/v1beta/organizations/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\00272\'/v1beta/organizations/{organization_id}:\014organization'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganization']._serialized_options = b'\222A\016\n\014Organization\202\323\344\223\002)*\'/v1beta/organizations/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListUserMemberships']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002%\022#/v1beta/users/{user_id}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetUserMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\0027\0225/v1beta/users/{user_id}/memberships/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateUserMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002C\0325/v1beta/users/{user_id}/memberships/{organization_id}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteUserMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\0027*5/v1beta/users/{user_id}/memberships/{organization_id}'
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListOrganizationMemberships']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\0025\0223/v1beta/organizations/{organization_id}/memberships'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002?\022=/v1beta/organizations/{organization_id}/memberships/{user_id}'
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['UpdateOrganizationMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002K\032=/v1beta/organizations/{organization_id}/memberships/{user_id}:\nmembership'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteOrganizationMembership']._serialized_options = b'\222A\014\n\nMembership\202\323\344\223\002?*=/v1beta/organizations/{organization_id}/memberships/{user_id}'
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetAuthenticatedUserSubscription']._serialized_options = b'\222A\016\n\014Subscription\202\323\344\223\002\033\022\031/v1beta/user/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetOrganizationSubscription']._serialized_options = b'\222A\016\n\014Subscription\202\323\344\223\0026\0224/v1beta/organizations/{organization_id}/subscription'
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CreateToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\027\"\016/v1beta/tokens:\005token'
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListTokens']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\020\022\016/v1beta/tokens'
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\033\022\031/v1beta/tokens/{token_id}'
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['DeleteToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\033*\031/v1beta/tokens/{token_id}'
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ValidateToken']._serialized_options = b'\222A\007\n\005Token\202\323\344\223\002\030\"\026/v1beta/validate_token'
  _MGMTPUBLICSERVICE.methods_by_name['GetRemainingCredit']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetRemainingCredit']._serialized_options = b'\222A\010\n\006Credit\202\323\344\223\002*\022(/v1beta/namespaces/{namespace_id}/credit'
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['CheckNamespace']._serialized_options = b'\222A\007\n\005Utils\202\323\344\223\002\034\"\027/v1beta/check-namespace:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['GetPipelineTriggerCount']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['GetPipelineTriggerCount']._serialized_options = b'\222A\010\n\006Metric\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022*/v1beta/metrics/vdp/pipeline/trigger-count'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerTableRecords']._serialized_options = b'\210\002\001\222A\010\n\006Metric\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/tables'
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListPipelineTriggerChartRecords']._serialized_options = b'\222A\010\n\006Metric\202\323\344\223\002%\022#/v1beta/metrics/vdp/pipeline/charts'
  _MGMTPUBLICSERVICE.methods_by_name['ListCreditConsumptionChartRecords']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['ListCreditConsumptionChartRecords']._serialized_options = b'\222A\010\n\006Metric\202\323\344\223\002\037\022\035/v1beta/metrics/credit/charts'
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthTokenIssuer']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\036\"\031/v1beta/auth/token_issuer:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogin']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\024\"\022/v1beta/auth/login'
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthLogout']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\025\"\023/v1beta/auth/logout'
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthChangePassword']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002!\"\034/v1beta/auth/change_password:\001*'
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._options = None
  _MGMTPUBLICSERVICE.methods_by_name['AuthValidateAccessToken']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002$\"\"/v1beta/auth/validate_access_token'
  _globals['_MGMTPUBLICSERVICE']._serialized_start=232
  _globals['_MGMTPUBLICSERVICE']._serialized_end=6740
# @@protoc_insertion_point(module_scope)
